Summary: GNU Bourne Again Shell (bash)
Name: bash
Version: 2.03
Release: 7_nw1
Group: Shells
Copyright: GPL
Packager: Brian Bruns <bruns@Magenet.com>
Source0: ftp://ftp.gnu.org/pub/gnu/bash-%{PACKAGE_VERSION}.tar.gz
Source1: bashrc
Source2: ftp://ftp.gnu.org/pub/gnu/bash-doc-%{version}.tar.gz
Patch0: bash-2.03-paths.patch
Patch1: bash-2.02-security.patch
Patch2: bash-2.02.1-arm.patch
Patch3: bash-log.diff
Patch4: bash-2.03-glibc.patch
BuildRoot: /var/tmp/%{name}-root

%description
Bash is an sh-compatible command language interpreter that
executes commands read from the standard input or from a
file.  Bash also incorporates useful features from the
Korn and C shells (ksh and csh).

Bash is ultimately intended to be a conformant implementation
of the IEEE Posix Shell and Tools specification (IEEE
Working Group 1003.2).

This version was modified with the patch from OJNK which allows
for user command logging in /var/log/histories

%package doc
Group: Shells
Summary: Documentation for the GNU Bourne Again Shell (bash)

%description doc
This is the separate documentation package for the GNU Bourne
Again Shell (bash).

%prep
%setup -q
mv doc maindoc
%setup -q -D -T -a 2
mv doc bashdoc
mv maindoc doc
%patch0 -p1 -b .paths
%patch1 -p1 -b .security
%patch2 -p1 -b .arm
%patch3 -p1 -b bash-log.diff
%patch4 -p1 -b .glibc
%build
./support/mkconffiles -s . -d . -v
CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="-s" \
    ./configure --prefix=$RPM_BUILD_ROOT/usr $RPM_ARCH-redhat-linux
#                --with-installed-readline
make

%install
rm -rf $RPM_BUILD_ROOT

make install

( cd $RPM_BUILD_ROOT
  mkdir -p ./bin ./etc
  mv ./usr/bin/bash ./bin/bash
  strip ./bin/bash
  gzip -9nf ./usr/info/bash.info*
  rm ./usr/info/dir
  install -m644 $RPM_SOURCE_DIR/bashrc ./etc/bashrc
  ln -sf bash.1 ./usr/man/man1/sh.1
  ln -sf bash ./bin/sh
)

# make manpages for bash builtins as per suggestion in DOC/README
cd doc
install -m 644 builtins.1 $RPM_BUILD_ROOT/usr/man/man1
sed -e '
/^\.SH NAME/, /\\- bash built-in commands, see \\fBbash\\fR(1)$/{
/^\.SH NAME/d
s/^bash, //
s/\\- bash built-in commands, see \\fBbash\\fR(1)$//
s/,//g
b
}
d
' builtins.1 > man.pages

# Avoid names from other packages
perl -pi -e 's/(kill|export|echo|pwd|test)/bash-\1/g' man.pages

for i in `cat man.pages` ; do
  echo .so man1/builtins.1 > $RPM_BUILD_ROOT/usr/man/man1/$i.1
done

# now turn man.pages into a filelist for the doc subpackage
cat man.pages |tr -s ' ' '\n' |sed '
1i\
%defattr(0644,root,man,0755)
s:^:/usr/man/man1/:
s/$/.1/
' > ../man.pages


%clean
rm -rf $RPM_BUILD_ROOT

# ***** bash doesn't use install-info. It's always listed in /usr/info/dir
# to prevent prereq loops
%post

HASBASH=""
HASSH=""

if [ ! -f /etc/shells ]; then
        > /etc/shells
fi

(while read line ; do
	if [ $line = /bin/bash ]; then
		HASBASH=1
	elif [ $line = /bin/sh ]; then
		HASSH=1
	fi
 done

 if [ -z "$HASBASH" ]; then
 	echo "/bin/bash" >> /etc/shells
 fi
 
 if [ -z "$HASSH" ]; then
	echo "/bin/sh" >> /etc/shells
fi) < /etc/shells

%files
%defattr(-,root,root)
%doc CHANGES COMPAT COPYING NEWS NOTES README Y2K CWRU/POSIX.NOTES
%doc doc/FAQ doc/INTRO doc/article.ms
%doc examples/bashdb/ examples/functions/ examples/misc/
%doc examples/scripts.noah/ examples/scripts.v2/ examples/scripts/
%doc examples/startup-files/
%config /etc/bashrc
/bin/bash
/bin/sh
/usr/info/bash.info.gz
/usr/man/man1/bash.1
/usr/man/man1/builtins.1
/usr/man/man1/sh.1
/usr/bin/bashbug
/usr/man/man1/bashbug.1

%files doc -f man.pages
%defattr(-,root,root)
%doc bashdoc/*

%changelog
* Thu Sep 16 1999 Rod m. Stewart <stewart@netwinder.org>
- glibc 2.1 patch for netinit/in.h (socket struct sockaddr)
- remove odin header file and library references
- remove check_environment("bash") function call in bash-2.03/variable.c
  must be part of odin, which we do not have

* Wed Mar 3 1999 Brian Bruns <bruns@MageNet.com>
- Found problems in the previous package I built.  This one was built
  wth the regular gcc and not pgcc.

* Sat Feb 27 1999  Brian Bruns <bruns@MageNet.com>
- Now uses a patch created by Odin that allows root to keep track of
  history files in /var/log/histories (more info at:
  http://www.ojnk.nu/~odin/)
- Built against glibc 2.0.7 with pgcc and options -O6 and -mpentiumpro
  (but will work without a pentium pro processor)

* Sun Feb 21 1999  Ian Macdonald <ianmacd@xs4all.nl>
- uses built-in readline again (or Linux won't boot)
- perl wasn't renaming kill.1 in doc subpackage (added g flag to substitution)

* Sat Feb 20 1999  Ian Macdonald <ianmacd@xs4all.nl>
- updated to 2.03
- dynamically linked with readline
- minor .spec file changes to facilitate build

* Thu Jan 14 1999 Jeff Johnson <jbj@redhat.com>
- rename man pages in bash-doc to avoid packaging conflicts (#606).

* Wed Dec 02 1998 Cristian Gafton <gafton@redhat.com>
- patch for the arm
- use $RPM_ARCH-redhat-linux as the build target

* Tue Oct  6 1998 Bill Nottingham <notting@redhat.com>
- rewrite %pre, axe %postun (to avoid prereq loops)

* Wed Aug 19 1998 Jeff Johnson <jbj@redhat.com>
- resurrect for RH 6.0.

* Sun Jul 26 1998 Jeff Johnson <jbj@redhat.com>
- update to 2.02.1

* Thu Jun 11 1998 Jeff Johnson <jbj@redhat.com>
- Package for 5.2.

* Mon Apr 20 1998 Ian Macdonald <ianmacd@xs4all.nl>
- added POSIX.NOTES doc file
- some extraneous doc files removed
- minor .spec file changes

* Sun Apr 19 1998 Ian Macdonald <ianmacd@xs4all.nl>
- upgraded to version 2.02
- Alpha, MIPS & Sparc patches removed due to lack of test platforms
- glibc & signal patches no longer required
- added documentation subpackage (doc)

* Fri Nov 07 1997 Donnie Barnes <djb@redhat.com>
- added signal handling patch from Dean Gaudet <dgaudet@arctic.org> that
  is based on a change made in bash 2.0.  Should fix some early exit
  problems with suspends and fg.

* Mon Oct 20 1997 Donnie Barnes <djb@redhat.com>
- added %clean

* Mon Oct 20 1997 Erik Troan <ewt@redhat.com>
- added comment explaining why install-info isn't used
- added mips patch 

* Fri Oct 17 1997 Donnie Barnes <djb@redhat.com>
- added BuildRoot

* Tue Jun 03 1997 Erik Troan <ewt@redhat.com>
- built against glibc
